@@ -8,10 +8,9 @@
 #' @inheritParams oddsratio_to_d
 #' @inheritParams phi
 #' @param alternative a character string specifying the alternative hypothesis;
-#'   Controls the type of CI returned: `"two.sided"` (two-sided CI; default),
-#'   `"greater"` (one-sided CI) or `"less"` (one-sided CI). Partial matching is
-#'   allowed (e.g., `"g"`, `"l"`, `"two"`...). See *One-Sided CIs* in
-#'   [effectsize_CIs].
+#'   Controls the type of CI returned: `"two.sided"` (default, two-sided CI),
+#'   `"greater"` or `"less"` (one-sided CI). Partial matching is allowed (e.g.,
+#'   `"g"`, `"l"`, `"two"`...). See *One-Sided CIs* in [effectsize_CIs].
 #' @param ... Ignored
 #'
 #' @details
@@ -22,6 +21,7 @@
 #' a good close approximation.
 #'
 #' @inheritSection effectsize_CIs CIs and Significance Tests
+#' @inheritSection print.effectsize_table Plotting with `see`
 #'
 #' @return A data frame with the effect size (`Cohens_g`, `Risk_ratio`
 #'   (possibly with the prefix `log_`), `Cohens_h`) and its CIs (`CI_low` and
@@ -52,11 +52,10 @@
 #' # Test 2 gives a negative result more than test 1!
 #'
 #' @export
-#' @importFrom stats complete.cases prop.test
 cohens_g <- function(x, y = NULL,
                      ci = 0.95, alternative = "two.sided",
                      ...) {
-  alternative <- match.arg(alternative, c("two.sided", "less", "greater"))
+  alternative <- .match.alt(alternative)
 
   if (.is_htest_of_type(x, "McNemar")) {
     return(effectsize(x, ci = ci, alternative = alternative))
@@ -92,9 +91,7 @@ cohens_g <- function(x, y = NULL,
 
   out <- data.frame(Cohens_g = g)
 
-  ci_method <- NULL
-  if (is.numeric(ci)) {
-    stopifnot(length(ci) == 1, ci < 1, ci > 0)
+  if (.test_ci(ci)) {
     out$CI <- ci
 
     n <- sum(b) + sum(c)
@@ -112,6 +109,8 @@ cohens_g <- function(x, y = NULL,
     out$CI_high <- res$conf.int[2] - 0.5
 
     ci_method <- list(method = "binomial")
+  } else {
+    ci_method <- alternative <- NULL
   }
 
   class(out) <- c("effectsize_table", "see_effectsize_table", class(out))
