@@ -6,6 +6,12 @@ options(digits = 3)
 
 set.seed(7)
 
+.eval_if_requireNamespace <- function(...) {
+  pkgs <- c(...)
+  knitr::opts_chunk$get("eval") &&
+    all(vapply(pkgs, requireNamespace, TRUE, quietly = TRUE))
+}
+
 ## -----------------------------------------------------------------------------
 library(effectsize)
 options(es.use_symbols = TRUE) # get nice symbols when printing! (On Windows, requires R >= 4.2.0)
@@ -28,7 +34,7 @@ food_class
 ## -----------------------------------------------------------------------------
 cramers_v(food_class, adjust = FALSE)
 
-tschuprows_t(food_class)
+tschuprows_t(food_class, adjust = FALSE)
 
 ## -----------------------------------------------------------------------------
 data("Music_preferences2")
@@ -45,7 +51,7 @@ pearsons_c(Music_preferences2)
 
 cohens_w(Music_preferences2) # > 1
 
-## ---- eval = requireNamespace("BayesFactor", quietly = TRUE), message=FALSE----
+## ----eval = .eval_if_requireNamespace("BayesFactor"), message=FALSE-----------
 library(BayesFactor)
 BFX <- contingencyTableBF(MPG_Gear, sampleType = "jointMulti")
 
@@ -76,9 +82,9 @@ cohens_w(O, p = E)
 fei(O, p = E)
 
 # Observed perfectly matches Expected
-(O1 <- c(E * 286))
+(O1 <- E * 286)
 
-fei(O1, p = E) 
+fei(O1, p = E)
 
 
 # Observed deviates maximally from Expected:
@@ -98,10 +104,12 @@ oddsratio(RCT_table)
 ## -----------------------------------------------------------------------------
 riskratio(RCT_table)
 
+arr(RCT_table)
+
 ## -----------------------------------------------------------------------------
 cohens_h(RCT_table)
 
-## ---- eval = requireNamespace("BayesFactor", quietly = TRUE)------------------
+## ----eval = .eval_if_requireNamespace("BayesFactor")--------------------------
 BFX <- contingencyTableBF(RCT_table, sampleType = "jointMulti")
 
 effectsize(BFX, type = "or")
